cheesecake.util.StdoutRedirector

Package cheesecake :: Module util :: Class StdoutRedirector |
[hide private]
[frames] | no frames]

## Class StdoutRedirector
source code

    object --+
             |
            StdoutRedirector

Redirect stdout to a temporary file.

Instance Methods | [hide private]
| __init__(self, filename=None) x.__init__(...) initializes x; see x.__class__.__doc__ for signature
| write(self, buf)
| flush(self)
| read_buffer(self) Return contents of the temporary file.
Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Variables | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, filename=None) (Constructor) | source code
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__ (inherited documentation)

### write(self, buf) | source code

### flush(self) | source code

### read_buffer(self) | source code
Return contents of the temporary file.